.. module:: plotting

.. _plotting:

Plotting
================

.. automodule:: ehtim.plotting.summary_plots
    :members:

.. automodule:: ehtim.plotting.comp_plots
    :members:

.. automodule:: ehtim.plotting.comparisons
    :members:


